Learn R Programming

ppls (version 2.0.0)

vcov.mypls: Variance-Covariance Matrix for Penalized PLS Coefficients

Description

Returns the estimated variance-covariance matrix of the regression coefficients from a jackknife-based PPLS model.

Usage

# S3 method for mypls
vcov(object, ...)

Value

A numeric matrix representing the variance-covariance matrix of the regression coefficients, or NULL if unavailable.

Arguments

object

An object of class "mypls", typically returned by jack.ppls.

...

Additional arguments (currently ignored).

Details

The function retrieves the covariance matrix stored in the object$covariance field. If this field is NULL, a warning is issued and the function returns NULL.

This method can be used in conjunction with coef.mypls and ttest.ppls to conduct inference on the coefficients of a penalized PLS model.

See Also

coef.mypls, jack.ppls, ttest.ppls

Examples

Run this code
set.seed(42)
X <- matrix(rnorm(30 * 100), ncol = 30)
y <- rnorm(100)

ppls.cv <- penalized.pls.cv(X, y, lambda = c(1, 10), ncomp = 3)
myjack <- jack.ppls(ppls.cv)
Sigma <- vcov(myjack)
Sigma[1:5, 1:5]

Run the code above in your browser using DataLab